OME, Go! (omego)
================

The omego command provides utilities for installing and managing OME applications.

|Build Status|

Getting Started
---------------

The only requirement for Python 2.7 and above is `cliff`_.

::

    $ pip install cliff

For Python 2.6, you will also need to install `argparse`_

::

    $ pip install argparse

With that, it's possible to execute scc:

::

    $ python scc.py

With that, it's possible to execute omego:

::

    $ python omego/main.py

Pip installation
-----------------

To install the latest release of omego use pip install:

::

    $ pip install scc
    $ omego

License
-------

omego is released under the GPL.

Copyright
---------

2013, The Open Microscopy Environment

.. _cliff: https://cliff.readthedocs.org
.. |Build Status| image:: https://travis-ci.org/ome/omego.png
   :target: http://travis-ci.org/ome/omego
